@@ -18,7 +18,7 @@ class AtlantisClient:
     @property
     def client_id(self):
         if self._client_id is None:
-            raise InvalidInitParameters('invalid initialization of the required parameters.')
+            raise InvalidInitParameters('Missing ATLANTIS_CLIENT_ID on AtlantisClient initialization.')
         return self._client_id
 
     @property
